@@ -29,12 +29,13 @@ from typing import (
     Optional,
     Pattern,
     Set,
+    Tuple,
     TypedDict,
     TypeVar,
     Union,
     cast,
 )
-from urllib.parse import urljoin, urlparse
+from urllib.parse import ParseResult, urljoin, urlparse, urlunparse
 
 from playwright._impl._api_structures import NameValue
 from playwright._impl._errors import (
@@ -189,6 +190,16 @@ def resolve_glob_base(base_url: Optional[str], match: str) -> str:
 
     # Escaped `\\?` behaves the same as `?` in our glob patterns.
     match = match.replace(r"\\?", "?")
+    # Special case about: URLs as they are not relative to base_url
+    if (
+        match.startswith("about:")
+        or match.startswith("data:")
+        or match.startswith("chrome:")
+        or match.startswith("edge:")
+        or match.startswith("file:")
+    ):
+        # about: and data: URLs are not relative to base_url, so we return them as is.
+        return match
     # Glob symbols may be escaped in the URL and some of them such as ? affect resolution,
     # so we replace them with safe components first.
     processed_parts = []
@@ -199,8 +210,12 @@ def resolve_glob_base(base_url: Optional[str], match: str) -> str:
         # Handle special case of http*://, note that the new schema has to be
         # a web schema so that slashes are properly inserted after domain.
         if index == 0 and token.endswith(":"):
-            # Using a simple replacement for the scheme part
-            processed_parts.append(map_token(token, "http:"))
+            # Replace any pattern with http:
+            if "*" in token or "{" in token:
+                processed_parts.append(map_token(token, "http:"))
+            else:
+                # Preserve explicit schema as is as it may affect trailing slashes after domain.
+                processed_parts.append(token)
             continue
         question_index = token.find("?")
         if question_index == -1:
@@ -211,34 +226,49 @@ def resolve_glob_base(base_url: Optional[str], match: str) -> str:
             processed_parts.append(new_prefix + new_suffix)
 
     relative_path = "/".join(processed_parts)
-    resolved_url = urljoin(base_url if base_url is not None else "", relative_path)
+    resolved, case_insensitive_part = resolve_base_url(base_url, relative_path)
 
-    for replacement, original in token_map.items():
-        resolved_url = resolved_url.replace(replacement, original, 1)
+    for token, original in token_map.items():
+        normalize = case_insensitive_part and token in case_insensitive_part
+        resolved = resolved.replace(
+            token, original.lower() if normalize else original, 1
+        )
 
-    return ensure_trailing_slash(resolved_url)
+    return resolved
 
 
-# In Node.js, new URL('http://localhost') returns 'http://localhost/'.
-# To ensure the same url matching behavior, do the same.
-def ensure_trailing_slash(url: str) -> str:
-    split = url.split("://", maxsplit=1)
-    if len(split) == 2:
-        # URL parser doesn't like strange/unknown schemes, so we replace it for parsing, then put it back
-        parsable_url = "http://" + split[1]
-    else:
-        # Given current rules, this should never happen _and_ still be a valid matcher. We require the protocol to be part of the match,
-        # so either the user is using a glob that starts with "*" (and none of this code is running), or the user actually has `something://` in `match`
-        parsable_url = url
-    parsed = urlparse(parsable_url, allow_fragments=True)
-    if len(split) == 2:
-        # Replace the scheme that we removed earlier
-        parsed = parsed._replace(scheme=split[0])
-    if parsed.path == "":
-        parsed = parsed._replace(path="/")
-        url = parsed.geturl()
+def resolve_base_url(
+    base_url: Optional[str], given_url: str
+) -> Tuple[str, Optional[str]]:
+    try:
+        url = nodelike_urlparse(
+            urljoin(base_url if base_url is not None else "", given_url)
+        )
+        resolved = urlunparse(url)
+        # Schema and domain are case-insensitive.
+        hostname_port = (
+            url.hostname or ""
+        )  # can't use parsed.netloc because it includes userinfo (username:password)
+        if url.port:
+            hostname_port += f":{url.port}"
+        case_insensitive_prefix = f"{url.scheme}://{hostname_port}"
+        return resolved, case_insensitive_prefix
+    except Exception:
+        return given_url, None
 
-    return url
+
+def nodelike_urlparse(url: str) -> ParseResult:
+    parsed = urlparse(url, allow_fragments=True)
+
+    # https://url.spec.whatwg.org/#special-scheme
+    is_special_url = parsed.scheme in ["http", "https", "ws", "wss", "ftp", "file"]
+    if is_special_url:
+        # special urls have a list path, list paths are serialized as follows: https://url.spec.whatwg.org/#url-path-serializer
+        # urllib diverges, so we patch it here
+        if parsed.path == "":
+            parsed = parsed._replace(path="/")
+
+    return parsed
 
 
 class HarLookupResult(TypedDict, total=False):
