@@ -14,6 +14,7 @@
 
 import json
 import pathlib
+import re
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -47,7 +48,7 @@ from playwright._impl._helper import (
     monotonic_time,
     to_impl,
 )
-from playwright._impl._js_handle import Serializable, parse_value, serialize_argument
+from playwright._impl._js_handle import Serializable
 from playwright._impl._str_utils import (
     escape_for_attribute_selector,
     escape_for_text_selector,
@@ -155,9 +156,10 @@ class Locator:
         force: bool = None,
         noWaitAfter: bool = None,
         trial: bool = None,
+        steps: int = None,
     ) -> None:
         params = locals_to_params(locals())
-        return await self._frame.click(self._selector, strict=True, **params)
+        return await self._frame._click(self._selector, strict=True, **params)
 
     async def dblclick(
         self,
@@ -169,6 +171,7 @@ class Locator:
         force: bool = None,
         noWaitAfter: bool = None,
         trial: bool = None,
+        steps: int = None,
     ) -> None:
         params = locals_to_params(locals())
         return await self._frame.dblclick(self._selector, strict=True, **params)
@@ -217,7 +220,8 @@ class Locator:
         noWaitAfter: bool = None,
         force: bool = None,
     ) -> None:
-        await self.fill("", timeout=timeout, force=force)
+        params = locals_to_params(locals())
+        await self._frame._fill(self._selector, value="", title="Clear", **params)
 
     def locator(
         self,
@@ -342,6 +346,20 @@ class Locator:
             f"{self._selector} >> internal:describe={json.dumps(description)}",
         )
 
+    @property
+    def description(self) -> Optional[str]:
+        try:
+            match = re.search(
+                r' >> internal:describe=("(?:[^"\\]|\\.)*")$', self._selector
+            )
+            if match:
+                description = json.loads(match.group(1))
+                if isinstance(description, str):
+                    return description
+        except (json.JSONDecodeError, ValueError):
+            pass
+        return None
+
     def filter(
         self,
         hasText: Union[str, Pattern[str]] = None,
@@ -413,6 +431,7 @@ class Locator:
         trial: bool = None,
         sourcePosition: Position = None,
         targetPosition: Position = None,
+        steps: int = None,
     ) -> None:
         params = locals_to_params(locals())
         del params["target"]
@@ -501,19 +520,17 @@ class Locator:
         )
 
     async def is_hidden(self, timeout: float = None) -> bool:
-        params = locals_to_params(locals())
+        # timeout is deprecated and does nothing
         return await self._frame.is_hidden(
             self._selector,
             strict=True,
-            **params,
         )
 
     async def is_visible(self, timeout: float = None) -> bool:
-        params = locals_to_params(locals())
+        # timeout is deprecated and does nothing
         return await self._frame.is_visible(
             self._selector,
             strict=True,
-            **params,
         )
 
     async def press(
@@ -724,21 +741,7 @@ class Locator:
         options: FrameExpectOptions,
         title: str = None,
     ) -> FrameExpectResult:
-        if "expectedValue" in options:
-            options["expectedValue"] = serialize_argument(options["expectedValue"])
-        result = await self._frame._channel.send_return_as_dict(
-            "expect",
-            self._frame._timeout,
-            {
-                "selector": self._selector,
-                "expression": expression,
-                **options,
-            },
-            title=title,
-        )
-        if result.get("received"):
-            result["received"] = parse_value(result["received"])
-        return result
+        return await self._frame._expect(self._selector, expression, options, title)
 
     async def highlight(self) -> None:
         await self._frame._highlight(self._selector)
