@@ -22,7 +22,6 @@ __export(page_exports, {
   Page: () => Page
 });
 module.exports = __toCommonJS(page_exports);
-var import_accessibility = require("./accessibility");
 var import_artifact = require("./artifact");
 var import_channelOwner = require("./channelOwner");
 var import_clientHelper = require("./clientHelper");
@@ -48,6 +47,7 @@ var import_stringUtils = require("../utils/isomorphic/stringUtils");
 var import_urlMatch = require("../utils/isomorphic/urlMatch");
 var import_manualPromise = require("../utils/isomorphic/manualPromise");
 var import_rtti = require("../utils/isomorphic/rtti");
+var import_consoleMessage = require("./consoleMessage");
 class Page extends import_channelOwner.ChannelOwner {
   constructor(parent, type, guid, initializer) {
     super(parent, type, guid, initializer);
@@ -64,7 +64,6 @@ class Page extends import_channelOwner.ChannelOwner {
     this._locatorHandlers = /* @__PURE__ */ new Map();
     this._browserContext = parent;
     this._timeoutSettings = new import_timeoutSettings.TimeoutSettings(this._platform, this._browserContext._timeoutSettings);
-    this.accessibility = new import_accessibility.Accessibility(this._channel);
     this.keyboard = new import_input.Keyboard(this);
     this.mouse = new import_input.Mouse(this);
     this.request = this._browserContext.request;
@@ -174,7 +173,6 @@ class Page extends import_channelOwner.ChannelOwner {
   _onClose() {
     this._closed = true;
     this._browserContext._pages.delete(this);
-    this._browserContext._backgroundPages.delete(this);
     this._disposeHarRouters();
     this.emit(import_events.Events.Page.Close, this);
   }
@@ -534,6 +532,14 @@ class Page extends import_channelOwner.ChannelOwner {
   async fill(selector, value, options) {
     return await this._mainFrame.fill(selector, value, options);
   }
+  async consoleMessages() {
+    const { messages } = await this._channel.consoleMessages();
+    return messages.map((message) => new import_consoleMessage.ConsoleMessage(this._platform, message, this, null));
+  }
+  async pageErrors() {
+    const { errors } = await this._channel.pageErrors();
+    return errors.map((error) => (0, import_errors.parseError)(error));
+  }
   locator(selector, options) {
     return this.mainFrame().locator(selector, options);
   }
@@ -627,6 +633,10 @@ class Page extends import_channelOwner.ChannelOwner {
   async waitForFunction(pageFunction, arg, options) {
     return await this._mainFrame.waitForFunction(pageFunction, arg, options);
   }
+  async requests() {
+    const { requests } = await this._channel.requests();
+    return requests.map((request) => import_network.Request.from(request));
+  }
   workers() {
     return [...this._workers];
   }
@@ -664,8 +674,7 @@ class Page extends import_channelOwner.ChannelOwner {
     return result.pdf;
   }
   async _snapshotForAI(options = {}) {
-    const result = await this._channel.snapshotForAI({ timeout: this._timeoutSettings.timeout(options) });
-    return result.snapshot;
+    return await this._channel.snapshotForAI({ timeout: this._timeoutSettings.timeout(options), track: options.track });
   }
 }
 class BindingCall extends import_channelOwner.ChannelOwner {
