@@ -38,9 +38,7 @@ var import_artifactDispatcher = require("./artifactDispatcher");
 var import_cdpSessionDispatcher = require("./cdpSessionDispatcher");
 var import_dialogDispatcher = require("./dialogDispatcher");
 var import_dispatcher = require("./dispatcher");
-var import_elementHandlerDispatcher = require("./elementHandlerDispatcher");
 var import_frameDispatcher = require("./frameDispatcher");
-var import_jsHandleDispatcher = require("./jsHandleDispatcher");
 var import_networkDispatchers = require("./networkDispatchers");
 var import_pageDispatcher = require("./pageDispatcher");
 var import_crBrowser = require("../chromium/crBrowser");
@@ -52,6 +50,8 @@ var import_crypto = require("../utils/crypto");
 var import_urlMatch = require("../../utils/isomorphic/urlMatch");
 var import_recorder = require("../recorder");
 var import_recorderApp = require("../recorder/recorderApp");
+var import_elementHandlerDispatcher = require("./elementHandlerDispatcher");
+var import_jsHandleDispatcher = require("./jsHandleDispatcher");
 class BrowserContextDispatcher extends import_dispatcher.Dispatcher {
   constructor(parentScope, context) {
     const requestContext = import_networkDispatchers.APIRequestContextDispatcher.from(parentScope, context.fetchRequest);
@@ -105,20 +105,13 @@ class BrowserContextDispatcher extends import_dispatcher.Dispatcher {
       this._dispatchEvent("pageError", { error: (0, import_errors.serializeError)(error), page: import_pageDispatcher.PageDispatcher.from(this, page) });
     });
     this.addObjectListener(import_browserContext.BrowserContext.Events.Console, (message) => {
-      const page = message.page();
-      if (this._shouldDispatchEvent(page, "console")) {
-        const pageDispatcher = import_pageDispatcher.PageDispatcher.from(this, page);
+      const pageDispatcher = import_pageDispatcher.PageDispatcher.fromNullable(this, message.page());
+      const workerDispatcher = import_pageDispatcher.WorkerDispatcher.fromNullable(this, message.worker());
+      if (this._shouldDispatchEvent(message.page(), "console") || workerDispatcher?._subscriptions.has("console")) {
         this._dispatchEvent("console", {
           page: pageDispatcher,
-          type: message.type(),
-          text: message.text(),
-          args: message.args().map((a) => {
-            const elementHandle = a.asElement();
-            if (elementHandle)
-              return import_elementHandlerDispatcher.ElementHandleDispatcher.from(import_frameDispatcher.FrameDispatcher.from(this, elementHandle._frame), elementHandle);
-            return import_jsHandleDispatcher.JSHandleDispatcher.fromJSHandle(pageDispatcher, a);
-          }),
-          location: message.location()
+          worker: workerDispatcher,
+          ...this.serializeConsoleMessage(message, workerDispatcher || pageDispatcher)
         });
       }
     });
@@ -129,10 +122,7 @@ class BrowserContextDispatcher extends import_dispatcher.Dispatcher {
       return true;
     };
     context.dialogManager.addDialogHandler(this._dialogHandler);
-    if (context._browser.options.name === "chromium") {
-      for (const page of context.backgroundPages())
-        this._dispatchEvent("backgroundPage", { page: import_pageDispatcher.PageDispatcher.from(this, page) });
-      this.addObjectListener(import_crBrowser.CRBrowserContext.CREvents.BackgroundPage, (page) => this._dispatchEvent("backgroundPage", { page: import_pageDispatcher.PageDispatcher.from(this, page) }));
+    if (context._browser.options.name === "chromium" && this._object._browser instanceof import_crBrowser.CRBrowser) {
       for (const serviceWorker of context.serviceWorkers())
         this._dispatchEvent("serviceWorker", { worker: new import_pageDispatcher.WorkerDispatcher(this, serviceWorker) });
       this.addObjectListener(import_crBrowser.CRBrowserContext.CREvents.ServiceWorker, (serviceWorker) => this._dispatchEvent("serviceWorker", { worker: new import_pageDispatcher.WorkerDispatcher(this, serviceWorker) }));
@@ -197,6 +187,19 @@ class BrowserContextDispatcher extends import_dispatcher.Dispatcher {
       return true;
     return false;
   }
+  serializeConsoleMessage(message, jsScope) {
+    return {
+      type: message.type(),
+      text: message.text(),
+      args: message.args().map((a) => {
+        const elementHandle = a.asElement();
+        if (elementHandle)
+          return import_elementHandlerDispatcher.ElementHandleDispatcher.from(import_frameDispatcher.FrameDispatcher.from(this, elementHandle._frame), elementHandle);
+        return import_jsHandleDispatcher.JSHandleDispatcher.fromJSHandle(jsScope, a);
+      }),
+      location: message.location()
+    };
+  }
   async createTempFiles(params, progress) {
     const dir = this._context._browser.options.artifactsDir;
     const tmpDir = import_path.default.join(dir, "upload-" + (0, import_crypto.createGuid)());
@@ -291,7 +294,7 @@ class BrowserContextDispatcher extends import_dispatcher.Dispatcher {
     await import_recorderApp.RecorderApp.show(this._context, params);
   }
   async disableRecorder(params, progress) {
-    const recorder = import_recorder.Recorder.existingForContext(this._context);
+    const recorder = await import_recorder.Recorder.existingForContext(this._context);
     if (recorder)
       recorder.setMode("none");
   }
