@@ -34,7 +34,6 @@ __export(page_exports, {
   Worker: () => Worker
 });
 module.exports = __toCommonJS(page_exports);
-var accessibility = __toESM(require("./accessibility"));
 var import_browserContext = require("./browserContext");
 var import_console = require("./console");
 var import_errors = require("./errors");
@@ -60,7 +59,8 @@ class Page extends import_instrumentation.SdkObject {
     this._closedState = "open";
     this._closedPromise = new import_manualPromise.ManualPromise();
     this._initializedPromise = new import_manualPromise.ManualPromise();
-    this._eventsToEmitAfterInitialized = [];
+    this._consoleMessages = [];
+    this._pageErrors = [];
     this._crashed = false;
     this.openScope = new import_utils.LongStandingScope();
     this._emulatedMedia = {};
@@ -73,14 +73,13 @@ class Page extends import_instrumentation.SdkObject {
     this._locatorHandlers = /* @__PURE__ */ new Map();
     this._lastLocatorHandlerUid = 0;
     this._locatorHandlerRunningCounter = 0;
+    this._networkRequests = [];
     // Aiming at 25 fps by default - each frame is 40ms, but we give some slack with 35ms.
     // When throttling for tracing, 200ms between frames, except for 10 frames around the action.
     this._frameThrottler = new FrameThrottler(10, 35, 200);
-    this.lastSnapshotFrameIds = [];
     this.attribution.page = this;
     this.delegate = delegate;
     this.browserContext = browserContext;
-    this.accessibility = new accessibility.Accessibility(delegate.getAccessibilityTree.bind(delegate));
     this.keyboard = new input.Keyboard(delegate.rawKeyboard, this);
     this.mouse = new input.Mouse(delegate.rawMouse, this);
     this.touchscreen = new input.Touchscreen(delegate.rawTouchscreen, this);
@@ -108,25 +107,26 @@ class Page extends import_instrumentation.SdkObject {
       Worker: "worker"
     };
   }
-  async reportAsNew(opener, error = void 0, contextEvent = import_browserContext.BrowserContext.Events.Page) {
+  async reportAsNew(opener, error) {
     if (opener) {
       const openerPageOrError = await opener.waitForInitializedOrError();
       if (openerPageOrError instanceof Page && !openerPageOrError.isClosed())
         this._opener = openerPageOrError;
     }
-    this._markInitialized(error, contextEvent);
+    this._markInitialized(error);
   }
-  _markInitialized(error = void 0, contextEvent = import_browserContext.BrowserContext.Events.Page) {
+  _markInitialized(error = void 0) {
     if (error) {
       if (this.browserContext.isClosingOrClosed())
         return;
       this.frameManager.createDummyMainFrameIfNeeded();
     }
     this._initialized = error || this;
-    this.emitOnContext(contextEvent, this);
-    for (const { event, args } of this._eventsToEmitAfterInitialized)
-      this.browserContext.emit(event, ...args);
-    this._eventsToEmitAfterInitialized = [];
+    this.emitOnContext(import_browserContext.BrowserContext.Events.Page, this);
+    for (const pageError of this._pageErrors)
+      this.emitOnContext(import_browserContext.BrowserContext.Events.PageError, pageError, this);
+    for (const message of this._consoleMessages)
+      this.emitOnContext(import_browserContext.BrowserContext.Events.Console, message);
     if (this.isClosed())
       this.emit(Page.Events.Close);
     else
@@ -144,14 +144,6 @@ class Page extends import_instrumentation.SdkObject {
       return;
     this.browserContext.emit(event, ...args);
   }
-  emitOnContextOnceInitialized(event, ...args) {
-    if (this.isStorageStatePage)
-      return;
-    if (this._initialized)
-      this.browserContext.emit(event, ...args);
-    else
-      this._eventsToEmitAfterInitialized.push({ event, args });
-  }
   async resetForReuse(progress) {
     await this.mainFrame().gotoImpl(progress, "about:blank", {});
     this._emulatedSize = void 0;
@@ -246,19 +238,41 @@ class Page extends import_instrumentation.SdkObject {
   extraHTTPHeaders() {
     return this._extraHTTPHeaders;
   }
+  addNetworkRequest(request) {
+    this._networkRequests.push(request);
+    ensureArrayLimit(this._networkRequests, 100);
+  }
+  networkRequests() {
+    return this._networkRequests;
+  }
   async onBindingCalled(payload, context) {
     if (this._closedState === "closed")
       return;
     await PageBinding.dispatch(this, payload, context);
   }
-  addConsoleMessage(type, args, location, text) {
-    const message = new import_console.ConsoleMessage(this, type, text, args, location);
+  addConsoleMessage(worker, type, args, location, text) {
+    const message = new import_console.ConsoleMessage(this, worker, type, text, args, location);
     const intercepted = this.frameManager.interceptConsoleMessage(message);
     if (intercepted) {
       args.forEach((arg) => arg.dispose());
       return;
     }
-    this.emitOnContextOnceInitialized(import_browserContext.BrowserContext.Events.Console, message);
+    this._consoleMessages.push(message);
+    ensureArrayLimit(this._consoleMessages, 200);
+    if (this._initialized)
+      this.emitOnContext(import_browserContext.BrowserContext.Events.Console, message);
+  }
+  consoleMessages() {
+    return this._consoleMessages;
+  }
+  addPageError(pageError) {
+    this._pageErrors.push(pageError);
+    ensureArrayLimit(this._pageErrors, 200);
+    if (this._initialized)
+      this.emitOnContext(import_browserContext.BrowserContext.Events.PageError, pageError, this);
+  }
+  pageErrors() {
+    return this._pageErrors;
   }
   async reload(progress, options) {
     return this.mainFrame().raceNavigationAction(progress, async () => {
@@ -334,6 +348,8 @@ class Page extends import_instrumentation.SdkObject {
     await this._performWaitForNavigationCheck(progress);
   }
   async _performWaitForNavigationCheck(progress) {
+    if (process.env.PLAYWRIGHT_SKIP_NAVIGATION_CHECK)
+      return;
     const mainFrame = this.frameManager.mainFrame();
     if (!mainFrame || !mainFrame.pendingDocument())
       return;
@@ -565,7 +581,8 @@ class Page extends import_instrumentation.SdkObject {
       this.closeReason = options.reason;
     const runBeforeUnload = !!options.runBeforeUnload;
     if (this._closedState !== "closing") {
-      this._closedState = "closing";
+      if (!runBeforeUnload)
+        this._closedState = "closing";
       await this.delegate.closePage(runBeforeUnload).catch((e) => import_debugLogger.debugLogger.log("error", e));
     }
     if (!runBeforeUnload)
@@ -648,21 +665,19 @@ class Page extends import_instrumentation.SdkObject {
     await Promise.all(this.frames().map((frame) => frame.hideHighlight().catch(() => {
     })));
   }
-  async snapshotForAI(progress) {
-    this.lastSnapshotFrameIds = [];
-    const snapshot = await snapshotFrameForAI(progress, this.mainFrame(), 0, this.lastSnapshotFrameIds);
-    return snapshot.join("\n");
+  async snapshotForAI(progress, options) {
+    const snapshot = await snapshotFrameForAI(progress, this.mainFrame(), options);
+    return { full: snapshot.full.join("\n"), incremental: snapshot.incremental?.join("\n") };
   }
 }
 class Worker extends import_instrumentation.SdkObject {
   constructor(parent, url) {
     super(parent, "worker");
+    this._executionContextPromise = new import_manualPromise.ManualPromise();
+    this._workerScriptLoaded = false;
     this.existingExecutionContext = null;
     this.openScope = new import_utils.LongStandingScope();
     this.url = url;
-    this._executionContextCallback = () => {
-    };
-    this._executionContextPromise = new Promise((x) => this._executionContextCallback = x);
   }
   static {
     this.Events = {
@@ -671,9 +686,15 @@ class Worker extends import_instrumentation.SdkObject {
   }
   createExecutionContext(delegate) {
     this.existingExecutionContext = new js.ExecutionContext(this, delegate, "worker");
-    this._executionContextCallback(this.existingExecutionContext);
+    if (this._workerScriptLoaded)
+      this._executionContextPromise.resolve(this.existingExecutionContext);
     return this.existingExecutionContext;
   }
+  workerScriptLoaded() {
+    this._workerScriptLoaded = true;
+    if (this.existingExecutionContext)
+      this._executionContextPromise.resolve(this.existingExecutionContext);
+  }
   didClose() {
     if (this.existingExecutionContext)
       this.existingExecutionContext.contextDestroyed("Worker was closed");
@@ -791,17 +812,17 @@ class FrameThrottler {
     }
   }
 }
-async function snapshotFrameForAI(progress, frame, frameOrdinal, frameIds) {
+async function snapshotFrameForAI(progress, frame, options) {
   const snapshot = await frame.retryWithProgressAndTimeouts(progress, [1e3, 2e3, 4e3, 8e3], async (continuePolling) => {
     try {
       const context = await progress.race(frame._utilityContext());
       const injectedScript = await progress.race(context.injectedScript());
-      const snapshotOrRetry = await progress.race(injectedScript.evaluate((injected, refPrefix) => {
+      const snapshotOrRetry = await progress.race(injectedScript.evaluate((injected, options2) => {
         const node = injected.document.body;
         if (!node)
           return true;
-        return injected.ariaSnapshot(node, { mode: "ai", refPrefix });
-      }, frameOrdinal ? "f" + frameOrdinal : ""));
+        return injected.incrementalAriaSnapshot(node, { mode: "ai", ...options2 });
+      }, { refPrefix: frame.seq ? "f" + frame.seq : "", track: options.track }));
       if (snapshotOrRetry === true)
         return continuePolling;
       return snapshotOrRetry;
@@ -811,33 +832,50 @@ async function snapshotFrameForAI(progress, frame, frameOrdinal, frameIds) {
       return continuePolling;
     }
   });
-  const lines = snapshot.split("\n");
-  const result = [];
-  for (const line of lines) {
+  const childSnapshotPromises = snapshot.iframeRefs.map((ref) => snapshotFrameRefForAI(progress, frame, ref, options));
+  const childSnapshots = await Promise.all(childSnapshotPromises);
+  const full = [];
+  let incremental;
+  if (snapshot.incremental !== void 0) {
+    incremental = snapshot.incremental.split("\n");
+    for (let i = 0; i < snapshot.iframeRefs.length; i++) {
+      const childSnapshot = childSnapshots[i];
+      if (childSnapshot.incremental)
+        incremental.push(...childSnapshot.incremental);
+      else if (childSnapshot.full.length)
+        incremental.push("- <changed> iframe [ref=" + snapshot.iframeRefs[i] + "]:", ...childSnapshot.full.map((l) => "  " + l));
+    }
+  }
+  for (const line of snapshot.full.split("\n")) {
     const match = line.match(/^(\s*)- iframe (?:\[active\] )?\[ref=([^\]]*)\]/);
     if (!match) {
-      result.push(line);
+      full.push(line);
       continue;
     }
     const leadingSpace = match[1];
     const ref = match[2];
-    const frameSelector = `aria-ref=${ref} >> internal:control=enter-frame`;
-    const frameBodySelector = `${frameSelector} >> body`;
-    const child = await progress.race(frame.selectors.resolveFrameForSelector(frameBodySelector, { strict: true }));
-    if (!child) {
-      result.push(line);
-      continue;
-    }
-    const frameOrdinal2 = frameIds.length + 1;
-    frameIds.push(child.frame._id);
-    try {
-      const childSnapshot = await snapshotFrameForAI(progress, child.frame, frameOrdinal2, frameIds);
-      result.push(line + ":", ...childSnapshot.map((l) => leadingSpace + "  " + l));
-    } catch {
-      result.push(line);
-    }
+    const childSnapshot = childSnapshots[snapshot.iframeRefs.indexOf(ref)] ?? { full: [] };
+    full.push(childSnapshot.full.length ? line + ":" : line);
+    full.push(...childSnapshot.full.map((l) => leadingSpace + "  " + l));
   }
-  return result;
+  return { full, incremental };
+}
+async function snapshotFrameRefForAI(progress, parentFrame, frameRef, options) {
+  const frameSelector = `aria-ref=${frameRef} >> internal:control=enter-frame`;
+  const frameBodySelector = `${frameSelector} >> body`;
+  const child = await progress.race(parentFrame.selectors.resolveFrameForSelector(frameBodySelector, { strict: true }));
+  if (!child)
+    return { full: [] };
+  try {
+    return await snapshotFrameForAI(progress, child.frame, options);
+  } catch {
+    return { full: [] };
+  }
+}
+function ensureArrayLimit(array, limit) {
+  if (array.length > limit)
+    return array.splice(0, limit / 10);
+  return [];
 }
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
