@@ -85,13 +85,8 @@ class WSServer {
       const url = new URL("http://localhost" + (request.url || ""));
       const id = String(++lastConnectionId);
       import_debugLogger.debugLogger.log("server", `[${id}] serving connection: ${request.url}`);
-      try {
-        const connection = this._delegate.onConnection(request, url, ws, id);
-        ws[kConnectionSymbol] = connection;
-      } catch (error) {
-        import_debugLogger.debugLogger.log("server", `[${id}] connection error: ${error}`);
-        ws.close(1011, String(error));
-      }
+      const connection = this._delegate.onConnection(request, url, ws, id);
+      ws[kConnectionSymbol] = connection;
     });
     return wsEndpoint;
   }
